You are viewing a plain text version of this content. The canonical link for it is here.
Posted to dev@pdfbox.apache.org by "ASF subversion and git services (JIRA)" <ji...@apache.org> on 2017/11/23 16:59:00 UTC

[jira] [Commented] (PDFBOX-4022) Cache ColorSpace instances in PDColorSpace.java

    [ https://issues.apache.org/jira/browse/PDFBOX-4022?page=com.atlassian.jira.plugin.system.issuetabpanels:comment-tabpanel&focusedCommentId=16264599#comment-16264599 ] 

ASF subversion and git services commented on PDFBOX-4022:
---------------------------------------------------------

Commit 1816171 from [~tilman] in branch 'pdfbox/trunk'
[ https://svn.apache.org/r1816171 ]

PDFBOX-4022: cache colorspace indirect objects

> Cache ColorSpace instances in PDColorSpace.java
> -----------------------------------------------
>
>                 Key: PDFBOX-4022
>                 URL: https://issues.apache.org/jira/browse/PDFBOX-4022
>             Project: PDFBox
>          Issue Type: Improvement
>          Components: Rendering
>    Affects Versions: 2.0.7, 2.0.8
>         Environment: Windows 10
>            Reporter: savan patel
>            Assignee: Tilman Hausherr
>              Labels: patch
>         Attachments: PDColorSpace.java.patch, selection.pdf
>
>
> I have a PDF which contains a lot of Images. Each time, pdfbox parse the image it uses the colorspace to parse it and most of the time colorspace is the same object. I tried to cache the colorspace instances in PDColorSpace.java as shown in the attached patch. For this particular PDF, this change improves the performance of parsing and rendering the images from 15 minutes down to 3 minutes. I shared the PDF.



--
This message was sent by Atlassian JIRA
(v6.4.14#64029)

---------------------------------------------------------------------
To unsubscribe, e-mail: dev-unsubscribe@pdfbox.apache.org
For additional commands, e-mail: dev-help@pdfbox.apache.org